README

This is the README file for the Amazon-API project. This page is for maintainers and those wanting to hack on the project. If all you want to do is install the Perl module you can download the Amazon::API module from CPAN.

Requirements for Building

Binaries

Libraries

Libraries needed to build certain Perl module dependencies:

Debian

RedHat

Perl Modules (Required)

Perl Modules (Optional)

If you don't have or want to install Perl::Tidy or Perl::Critic set LINT=off when running make

make LINT=off

Building the CPAN Distribution

git clone https://github.com/rlauer6/Amazon-API.git
cd Amazon-API
make

Author

Rob Lauer rclauer@gmail.com