README
This is the README file for the Amazon-API project. This
page is for maintainers and those wanting to hack on the project. If
all you want to do is install the Perl module you can download the
Amazon::API module
from CPAN.
Requirements for Building
Binaries
makegitgcc
Libraries
Libraries needed to build certain Perl module dependencies:
Debian
- libssl3, libssl-dev
- libexpat1
- zlib1g, zlib1g-dev
RedHat
- openssl-libs, oppenssl-devl
- expat, expat-devl
- zlib, zlib-devl
Perl Modules (Required)
CPAN::Maker>= 2.0.1Markdown::RenderCPAN::Maker::Bootstrapper>= 2.0.3Module::ScanDeps::StaticPod::MarkdownPod::HTML2PodList::MoreUtilsJSON::XS
- ...and possibly others
Perl Modules (Optional)
Perl::TidyPerl::Critic
If you don't have or want to install Perl::Tidy or Perl::Critic
set LINT=off when running make
make LINT=off
Building the CPAN Distribution
git clone https://github.com/rlauer6/Amazon-API.git
cd Amazon-API
make
Author
Rob Lauer rclauer@gmail.com